@@ -2,9 +2,11 @@ import copy
 
 from ipywidgets import (
     Widget, DOMWidget, Box, Color, CallbackDispatcher, widget_serialization,
-    interactive
+    interactive, Style
 )
 
+from ipywidgets.widgets.trait_types import InstanceDict
+
 from traitlets import (
     Float, Unicode, Int, Tuple, List, Instance, Bool, Dict, Enum,
     link, observe, default, validate, TraitError, Union
@@ -22,6 +24,12 @@ from ._version import EXTENSION_VERSION
 
 def_loc = [0.0, 0.0]
 allowed_crs = ['Earth', 'EPSG3395', 'EPSG3857', 'EPSG4326', 'Base', 'Simple']
+allowed_cursor = ['alias', 'cell', 'grab', 'move', 'crosshair', 'context-menu',
+                  'n-resize', 'ne-resize', 'e-resize', 'se-resize', 's-resize',
+                  'sw-resize', 'w-resize', 'nw-resize', 'nesw-resize',
+                  'nwse-resize', 'row-resize', 'col-resize', 'copy', 'default',
+                  'grabbing', 'help', 'no-drop', 'not-allowed', 'pointer',
+                  'progress', 'text', 'wait', 'zoom-in', 'zoom-out']
 
 
 def basemap_to_tiles(bm, day='yesterday', **kwargs):
@@ -747,6 +755,16 @@ class DrawControl(Control):
         self.send({'msg': 'clear_markers'})
 
 
+class MapStyle(Style, Widget):
+    """ Map Style Widget """
+    _model_name = Unicode('LeafletMapStyleModel').tag(sync=True)
+    _model_module = Unicode("jupyter-leaflet").tag(sync=True)
+
+    _model_module_version = Unicode(EXTENSION_VERSION).tag(sync=True)
+
+    cursor = Enum(values=allowed_cursor, default_value='grab').tag(sync=True)
+
+
 class Map(DOMWidget, InteractMixin):
     _view_name = Unicode('LeafletMapView').tag(sync=True)
     _model_name = Unicode('LeafletMapModel').tag(sync=True)
@@ -797,9 +815,18 @@ class Map(DOMWidget, InteractMixin):
     # zoom_animation = Bool(?).tag(sync=True, o=True)
     zoom_animation_threshold = Int(4).tag(sync=True, o=True)
     # marker_zoom_animation = Bool(?).tag(sync=True, o=True)
+    fullscreen = Bool(False).tag(sync=True, o=True)
 
     options = List(trait=Unicode).tag(sync=True)
 
+    style = InstanceDict(MapStyle).tag(sync=True, **widget_serialization)
+    default_style = InstanceDict(MapStyle).tag(sync=True, **widget_serialization)
+    dragging_style = InstanceDict(MapStyle).tag(sync=True, **widget_serialization)
+
+    @default('dragging_style')
+    def _default_dragging_style(self):
+        return {'cursor': 'move'}
+
     @default('options')
     def _default_options(self):
         return [name for name in self.traits(o=True)]
